import 'dart:io' as io;
import 'dart:io';
import 'dart:typed_data';
import 'package:path/path.dart' as path;

import '../utils/logger.dart';

const libext = "/lib/langauge";
const config_file_name = "/config.json";
const instruction_file_name = "/instruction.txt";
const instruction_file_path = '/bin/src/static_files/instructions.txt';

class FileOperations {
  void createLanguageConfig() async {
    String languageDirectory = await _createDirectoryIfNotExist();
    String languageConfigPath =
        await _createConfigPathIfNotExist(languageDirectory);
    await _createInstructionIfNotExist(languageDirectory);
  }

  /// Create language directory if not exist
  _createDirectoryIfNotExist() async {
    final Directory langDirectory = Directory('${path.current + libext}');
    Log.print(langDirectory.path);
    if (await langDirectory.exists()) {
      return langDirectory.path;
    } else {
      langDirectory.create(recursive: true).then((value) {});
    }
    return langDirectory.path;
  }

  _createConfigPathIfNotExist(String languageDirectory) async {
    File file = await File(languageDirectory + config_file_name);
    if (!(await file.exists())) {
      file.writeAsString('''{
  "language_support": [
    {
      "english": "en",
      "hindi": "hn"
    }
  ]
}''');
    } else {
      Log.error("Config File already Exist");
    }

    return file.path;
  }

  _createInstructionIfNotExist(String languageDirectory) async {
    File sourceFile = File(io.Directory.current.path + instruction_file_path);
    File destinationfile =
        await File(languageDirectory + instruction_file_name);

    if (!(await destinationfile.exists())) {
      destinationfile.writeAsString(await sourceFile.readAsString());
    } else {
      Log.error("Config File already Exist");
    }

    return destinationfile.path;
  }
}
